bytes_to_uint

Function bytes_to_uint 

pub fn bytes_to_uint<C: Curve>(bytes: &FieldBytes<C>) -> C::Uint
Decode the provided FieldBytes as an integer.

Note that the resulting integer is the raw representation of the given bytes and is not reduced by any modulus.