pub fn uint_to_bytes<C: Curve>(uint: &C::Uint) -> FieldBytes<C>Expand description
Encode the provided integer as FieldBytes.
Note that the output may be truncated if it overflows the width of FieldBytes.
pub fn uint_to_bytes<C: Curve>(uint: &C::Uint) -> FieldBytes<C>Encode the provided integer as FieldBytes.
Note that the output may be truncated if it overflows the width of FieldBytes.