pub fn bytes_to_uint<C: Curve>(bytes: &FieldBytes<C>) -> C::UintExpand description
Decode the provided FieldBytes as an integer.
Note that the resulting integer is the raw representation of the given bytes and is not
reduced by any modulus.
pub fn bytes_to_uint<C: Curve>(bytes: &FieldBytes<C>) -> C::UintDecode the provided FieldBytes as an integer.
Note that the resulting integer is the raw representation of the given bytes and is not
reduced by any modulus.